# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.challenge import Challenge  # noqa: E501
from agilicus_api.rest import ApiException

class TestChallenge(unittest.TestCase):
    """Challenge unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Challenge
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.challenge.Challenge()  # noqa: E501
        if include_optional :
            return Challenge(
                metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                spec = agilicus_api.models.challenge_spec.ChallengeSpec(
                    challenge_type = '0', 
                    challenge_types = [
                        '0'
                        ], 
                    user_id = '123', 
                    send_now = True, 
                    timeout_seconds = 1, 
                    response_uri = 'https://auth.egov.city/mfa-answer', 
                    origin = '0', 
                    challenge_endpoints = [
                        agilicus_api.models.challenge_endpoint.ChallengeEndpoint(
                            endpoint = '0', 
                            type = '0', )
                        ], ), 
                status = agilicus_api.models.challenge_status.ChallengeStatus(
                    state = 'issued', 
                    public_challenge = '0', )
            )
        else :
            return Challenge(
                spec = agilicus_api.models.challenge_spec.ChallengeSpec(
                    challenge_type = '0', 
                    challenge_types = [
                        '0'
                        ], 
                    user_id = '123', 
                    send_now = True, 
                    timeout_seconds = 1, 
                    response_uri = 'https://auth.egov.city/mfa-answer', 
                    origin = '0', 
                    challenge_endpoints = [
                        agilicus_api.models.challenge_endpoint.ChallengeEndpoint(
                            endpoint = '0', 
                            type = '0', )
                        ], ),
        )

    def testChallenge(self):
        """Test Challenge"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.certificates_api import CertificatesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestCertificatesApi(unittest.TestCase):
    """CertificatesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.certificates_api.CertificatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cert(self):
        """Test case for create_cert

        Creates a X509Certificate  # noqa: E501
        """
        pass

    def test_delete_agent_csr(self):
        """Test case for delete_agent_csr

        Delete a CertSigningReq  # noqa: E501
        """
        pass

    def test_delete_cert(self):
        """Test case for delete_cert

        Delete a X509Certificate  # noqa: E501
        """
        pass

    def test_delete_csr(self):
        """Test case for delete_csr

        Delete a CertSigningReq  # noqa: E501
        """
        pass

    def test_get_cert(self):
        """Test case for get_cert

        Get a X509Certificate  # noqa: E501
        """
        pass

    def test_get_csr(self):
        """Test case for get_csr

        Get a CertSigningReq  # noqa: E501
        """
        pass

    def test_list_certs(self):
        """Test case for list_certs

        list certificates  # noqa: E501
        """
        pass

    def test_list_csr(self):
        """Test case for list_csr

        list certificate signing requests  # noqa: E501
        """
        pass

    def test_replace_csr(self):
        """Test case for replace_csr

        Update a CertSigningReq  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorProxyRequestStatsDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'started': 'int',
        'finished': 'int',
        'status_1xx': 'int',
        'status_2xx': 'int',
        'status_3xx': 'int',
        'status_4xx': 'int',
        'status_5xx': 'int',
        'status_unknown': 'int',
        'failed_authentication': 'int',
        'failed_authorisation': 'int'
    }

    attribute_map = {
        'started': 'started',
        'finished': 'finished',
        'status_1xx': 'status_1xx',
        'status_2xx': 'status_2xx',
        'status_3xx': 'status_3xx',
        'status_4xx': 'status_4xx',
        'status_5xx': 'status_5xx',
        'status_unknown': 'status_unknown',
        'failed_authentication': 'failed_authentication',
        'failed_authorisation': 'failed_authorisation'
    }

    def __init__(self, started=None, finished=None, status_1xx=None, status_2xx=None, status_3xx=None, status_4xx=None, status_5xx=None, status_unknown=None, failed_authentication=None, failed_authorisation=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorProxyRequestStatsDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._started = None
        self._finished = None
        self._status_1xx = None
        self._status_2xx = None
        self._status_3xx = None
        self._status_4xx = None
        self._status_5xx = None
        self._status_unknown = None
        self._failed_authentication = None
        self._failed_authorisation = None
        self.discriminator = None

        self.started = started
        self.finished = finished
        self.status_1xx = status_1xx
        self.status_2xx = status_2xx
        self.status_3xx = status_3xx
        self.status_4xx = status_4xx
        self.status_5xx = status_5xx
        self.status_unknown = status_unknown
        self.failed_authentication = failed_authentication
        self.failed_authorisation = failed_authorisation

    @property
    def started(self):
        """Gets the started of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The total number of requests started by the proxy  # noqa: E501

        :return: The started of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._started

    @started.setter
    def started(self, started):
        """Sets the started of this AgentConnectorProxyRequestStatsDetails.

        The total number of requests started by the proxy  # noqa: E501

        :param started: The started of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and started is None:  # noqa: E501
            raise ValueError("Invalid value for `started`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                started is not None and started < 0):  # noqa: E501
            raise ValueError("Invalid value for `started`, must be a value greater than or equal to `0`")  # noqa: E501

        self._started = started

    @property
    def finished(self):
        """Gets the finished of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The total number of requests finished by the proxy.  # noqa: E501

        :return: The finished of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._finished

    @finished.setter
    def finished(self, finished):
        """Sets the finished of this AgentConnectorProxyRequestStatsDetails.

        The total number of requests finished by the proxy.  # noqa: E501

        :param finished: The finished of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and finished is None:  # noqa: E501
            raise ValueError("Invalid value for `finished`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                finished is not None and finished < 0):  # noqa: E501
            raise ValueError("Invalid value for `finished`, must be a value greater than or equal to `0`")  # noqa: E501

        self._finished = finished

    @property
    def status_1xx(self):
        """Gets the status_1xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 100 and 199   # noqa: E501

        :return: The status_1xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_1xx

    @status_1xx.setter
    def status_1xx(self, status_1xx):
        """Sets the status_1xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 100 and 199   # noqa: E501

        :param status_1xx: The status_1xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_1xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_1xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_1xx is not None and status_1xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_1xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_1xx = status_1xx

    @property
    def status_2xx(self):
        """Gets the status_2xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 200 and 299   # noqa: E501

        :return: The status_2xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_2xx

    @status_2xx.setter
    def status_2xx(self, status_2xx):
        """Sets the status_2xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 200 and 299   # noqa: E501

        :param status_2xx: The status_2xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_2xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_2xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_2xx is not None and status_2xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_2xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_2xx = status_2xx

    @property
    def status_3xx(self):
        """Gets the status_3xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 300 and 399   # noqa: E501

        :return: The status_3xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_3xx

    @status_3xx.setter
    def status_3xx(self, status_3xx):
        """Sets the status_3xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 300 and 399   # noqa: E501

        :param status_3xx: The status_3xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_3xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_3xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_3xx is not None and status_3xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_3xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_3xx = status_3xx

    @property
    def status_4xx(self):
        """Gets the status_4xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 400 and 499   # noqa: E501

        :return: The status_4xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_4xx

    @status_4xx.setter
    def status_4xx(self, status_4xx):
        """Sets the status_4xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 400 and 499   # noqa: E501

        :param status_4xx: The status_4xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_4xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_4xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_4xx is not None and status_4xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_4xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_4xx = status_4xx

    @property
    def status_5xx(self):
        """Gets the status_5xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 500 and 599   # noqa: E501

        :return: The status_5xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_5xx

    @status_5xx.setter
    def status_5xx(self, status_5xx):
        """Sets the status_5xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 500 and 599   # noqa: E501

        :param status_5xx: The status_5xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_5xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_5xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_5xx is not None and status_5xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_5xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_5xx = status_5xx

    @property
    def status_unknown(self):
        """Gets the status_unknown of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with an unknown status code   # noqa: E501

        :return: The status_unknown of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_unknown

    @status_unknown.setter
    def status_unknown(self, status_unknown):
        """Sets the status_unknown of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with an unknown status code   # noqa: E501

        :param status_unknown: The status_unknown of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_unknown is None:  # noqa: E501
            raise ValueError("Invalid value for `status_unknown`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_unknown is not None and status_unknown < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_unknown`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_unknown = status_unknown

    @property
    def failed_authentication(self):
        """Gets the failed_authentication of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which failed authentication.   # noqa: E501

        :return: The failed_authentication of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._failed_authentication

    @failed_authentication.setter
    def failed_authentication(self, failed_authentication):
        """Sets the failed_authentication of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which failed authentication.   # noqa: E501

        :param failed_authentication: The failed_authentication of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_authentication is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_authentication`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                failed_authentication is not None and failed_authentication < 0):  # noqa: E501
            raise ValueError("Invalid value for `failed_authentication`, must be a value greater than or equal to `0`")  # noqa: E501

        self._failed_authentication = failed_authentication

    @property
    def failed_authorisation(self):
        """Gets the failed_authorisation of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which failed authorisation.   # noqa: E501

        :return: The failed_authorisation of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._failed_authorisation

    @failed_authorisation.setter
    def failed_authorisation(self, failed_authorisation):
        """Sets the failed_authorisation of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which failed authorisation.   # noqa: E501

        :param failed_authorisation: The failed_authorisation of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_authorisation is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_authorisation`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                failed_authorisation is not None and failed_authorisation < 0):  # noqa: E501
            raise ValueError("Invalid value for `failed_authorisation`, must be a value greater than or equal to `0`")  # noqa: E501

        self._failed_authorisation = failed_authorisation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorProxyRequestStatsDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorProxyRequestStatsDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from agilicus_api.api_client import ApiClient
from agilicus_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class PolicyApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_challenge_decision(self, mfa_challenge_question, **kwargs):  # noqa: E501
        """evaluate a policy challenge decision  # noqa: E501

        Evaluate a policy challenge decision to determine if the user should be forced to answer a challenge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_challenge_decision(mfa_challenge_question, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MFAChallengeQuestion mfa_challenge_question: The MFA Challenge Question to ask (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MFAChallengeAnswer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_challenge_decision_with_http_info(mfa_challenge_question, **kwargs)  # noqa: E501

    def get_challenge_decision_with_http_info(self, mfa_challenge_question, **kwargs):  # noqa: E501
        """evaluate a policy challenge decision  # noqa: E501

        Evaluate a policy challenge decision to determine if the user should be forced to answer a challenge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_challenge_decision_with_http_info(mfa_challenge_question, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MFAChallengeQuestion mfa_challenge_question: The MFA Challenge Question to ask (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MFAChallengeAnswer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['mfa_challenge_question']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_challenge_decision" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'mfa_challenge_question' is set
        if self.api_client.client_side_validation and ('mfa_challenge_question' not in local_var_params or  # noqa: E501
                                                        local_var_params['mfa_challenge_question'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mfa_challenge_question` when calling `get_challenge_decision`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mfa_challenge_question' in local_var_params:
            body_params = local_var_params['mfa_challenge_question']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data/authentication/mfa_policy/allow', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MFAChallengeAnswer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_enrollment_decision(self, mfa_enrollment_question, **kwargs):  # noqa: E501
        """evaluate a policy enrollment decision  # noqa: E501

        Evaluate a policy enrollment decision to determine if the user should be forced to enroll  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_enrollment_decision(mfa_enrollment_question, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MFAEnrollmentQuestion mfa_enrollment_question: The MFA Enrollment Question to ask (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MFAEnrollmentAnswer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_enrollment_decision_with_http_info(mfa_enrollment_question, **kwargs)  # noqa: E501

    def get_enrollment_decision_with_http_info(self, mfa_enrollment_question, **kwargs):  # noqa: E501
        """evaluate a policy enrollment decision  # noqa: E501

        Evaluate a policy enrollment decision to determine if the user should be forced to enroll  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_enrollment_decision_with_http_info(mfa_enrollment_question, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MFAEnrollmentQuestion mfa_enrollment_question: The MFA Enrollment Question to ask (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MFAEnrollmentAnswer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['mfa_enrollment_question']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_enrollment_decision" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'mfa_enrollment_question' is set
        if self.api_client.client_side_validation and ('mfa_enrollment_question' not in local_var_params or  # noqa: E501
                                                        local_var_params['mfa_enrollment_question'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mfa_enrollment_question` when calling `get_enrollment_decision`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mfa_enrollment_question' in local_var_params:
            body_params = local_var_params['mfa_enrollment_question']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data/authentication/enrollment/allow', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MFAEnrollmentAnswer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def map_attributes(self, map_attributes_question, **kwargs):  # noqa: E501
        """map attributes of a user  # noqa: E501

        map attributes of a user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.map_attributes(map_attributes_question, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MapAttributesQuestion map_attributes_question: The attributes to map and information used to gather them (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MapAttributesAnswer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.map_attributes_with_http_info(map_attributes_question, **kwargs)  # noqa: E501

    def map_attributes_with_http_info(self, map_attributes_question, **kwargs):  # noqa: E501
        """map attributes of a user  # noqa: E501

        map attributes of a user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.map_attributes_with_http_info(map_attributes_question, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MapAttributesQuestion map_attributes_question: The attributes to map and information used to gather them (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MapAttributesAnswer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['map_attributes_question']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method map_attributes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'map_attributes_question' is set
        if self.api_client.client_side_validation and ('map_attributes_question' not in local_var_params or  # noqa: E501
                                                        local_var_params['map_attributes_question'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `map_attributes_question` when calling `map_attributes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'map_attributes_question' in local_var_params:
            body_params = local_var_params['map_attributes_question']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data/authentication/attribute_mapping/map_attributes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MapAttributesAnswer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.create_session_and_token_request import CreateSessionAndTokenRequest  # noqa: E501
from agilicus_api.rest import ApiException

class TestCreateSessionAndTokenRequest(unittest.TestCase):
    """CreateSessionAndTokenRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateSessionAndTokenRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.create_session_and_token_request.CreateSessionAndTokenRequest()  # noqa: E501
        if include_optional :
            return CreateSessionAndTokenRequest(
                create_token_request = agilicus_api.models.create_token_request.CreateTokenRequest(
                    sub = '123', 
                    org = '123', 
                    roles = {
                        'key' : '0'
                        }, 
                    audiences = [
                        '0'
                        ], 
                    time_validity = agilicus_api.models.time_validity.TimeValidity(
                        duration = 56, ), 
                    hosts = [
                        agilicus_api.models.host_permissions.HostPermissions(
                            upstream_host = '0', 
                            app_id = '123', 
                            admin_org_id = '123', 
                            allowed_list = [
                                agilicus_api.models.rendered_rule.RenderedRule(
                                    methods = [
                                        'get'
                                        ], 
                                    paths = [
                                        '0'
                                        ], 
                                    query_parameters = [
                                        agilicus_api.models.rendered_query_parameter.RenderedQueryParameter(
                                            name = '0', 
                                            exact_match = '0', )
                                        ], 
                                    body = agilicus_api.models.rendered_rule_body.RenderedRuleBody(
                                        json = [
                                            agilicus_api.models.json_body_constraint.JSONBodyConstraint(
                                                name = '0', 
                                                exact_match = '0', 
                                                match_type = 'string', 
                                                pointer = '/foo/0/a~1b/2', )
                                            ], ), )
                                ], )
                        ], 
                    token_validity = agilicus_api.models.token_validity.TokenValidity(
                        start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        duration = 56, 
                        end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        does_not_expire = False, ), 
                    session = '123', 
                    scopes = [
                        'urn:agilicus:users:owner'
                        ], ), 
                session = agilicus_api.models.session.Session(
                    metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                    spec = agilicus_api.models.sessions_spec.SessionsSpec(
                        user_id = 'asdfghjklmn123', 
                        org_id = 'asdfghjklmn123', 
                        revoked = False, 
                        number_of_logins = 3, 
                        number_of_failed_multi_factor_challenges = 3, ), )
            )
        else :
            return CreateSessionAndTokenRequest(
                create_token_request = agilicus_api.models.create_token_request.CreateTokenRequest(
                    sub = '123', 
                    org = '123', 
                    roles = {
                        'key' : '0'
                        }, 
                    audiences = [
                        '0'
                        ], 
                    time_validity = agilicus_api.models.time_validity.TimeValidity(
                        duration = 56, ), 
                    hosts = [
                        agilicus_api.models.host_permissions.HostPermissions(
                            upstream_host = '0', 
                            app_id = '123', 
                            admin_org_id = '123', 
                            allowed_list = [
                                agilicus_api.models.rendered_rule.RenderedRule(
                                    methods = [
                                        'get'
                                        ], 
                                    paths = [
                                        '0'
                                        ], 
                                    query_parameters = [
                                        agilicus_api.models.rendered_query_parameter.RenderedQueryParameter(
                                            name = '0', 
                                            exact_match = '0', )
                                        ], 
                                    body = agilicus_api.models.rendered_rule_body.RenderedRuleBody(
                                        json = [
                                            agilicus_api.models.json_body_constraint.JSONBodyConstraint(
                                                name = '0', 
                                                exact_match = '0', 
                                                match_type = 'string', 
                                                pointer = '/foo/0/a~1b/2', )
                                            ], ), )
                                ], )
                        ], 
                    token_validity = agilicus_api.models.token_validity.TokenValidity(
                        start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        duration = 56, 
                        end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        does_not_expire = False, ), 
                    session = '123', 
                    scopes = [
                        'urn:agilicus:users:owner'
                        ], ),
                session = agilicus_api.models.session.Session(
                    metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                    spec = agilicus_api.models.sessions_spec.SessionsSpec(
                        user_id = 'asdfghjklmn123', 
                        org_id = 'asdfghjklmn123', 
                        revoked = False, 
                        number_of_logins = 3, 
                        number_of_failed_multi_factor_challenges = 3, ), ),
        )

    def testCreateSessionAndTokenRequest(self):
        """Test CreateSessionAndTokenRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'name_slug': 'str',
        'org_id': 'str',
        'max_number_connections': 'int',
        'connection_uri': 'str',
        'service_account_required': 'bool',
        'local_authentication_enabled': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'name_slug': 'name_slug',
        'org_id': 'org_id',
        'max_number_connections': 'max_number_connections',
        'connection_uri': 'connection_uri',
        'service_account_required': 'service_account_required',
        'local_authentication_enabled': 'local_authentication_enabled'
    }

    def __init__(self, name=None, name_slug=None, org_id=None, max_number_connections=None, connection_uri=None, service_account_required=None, local_authentication_enabled=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._name_slug = None
        self._org_id = None
        self._max_number_connections = None
        self._connection_uri = None
        self._service_account_required = None
        self._local_authentication_enabled = None
        self.discriminator = None

        self.name = name
        if name_slug is not None:
            self.name_slug = name_slug
        self.org_id = org_id
        if max_number_connections is not None:
            self.max_number_connections = max_number_connections
        if connection_uri is not None:
            self.connection_uri = connection_uri
        if service_account_required is not None:
            self.service_account_required = service_account_required
        if local_authentication_enabled is not None:
            self.local_authentication_enabled = local_authentication_enabled

    @property
    def name(self):
        """Gets the name of this AgentConnectorSpec.  # noqa: E501

        A descriptive name for the connector  # noqa: E501

        :return: The name of this AgentConnectorSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AgentConnectorSpec.

        A descriptive name for the connector  # noqa: E501

        :param name: The name of this AgentConnectorSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def name_slug(self):
        """Gets the name_slug of this AgentConnectorSpec.  # noqa: E501

        A human readable slug to identify a resource and that is rfc1035 label compliant. The length has been restricted to 20 characters such that this name can be concatenated with other names or slugs. A slug is readOnly as it is generated by the backend resource.   # noqa: E501

        :return: The name_slug of this AgentConnectorSpec.  # noqa: E501
        :rtype: str
        """
        return self._name_slug

    @name_slug.setter
    def name_slug(self, name_slug):
        """Sets the name_slug of this AgentConnectorSpec.

        A human readable slug to identify a resource and that is rfc1035 label compliant. The length has been restricted to 20 characters such that this name can be concatenated with other names or slugs. A slug is readOnly as it is generated by the backend resource.   # noqa: E501

        :param name_slug: The name_slug of this AgentConnectorSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name_slug is not None and len(name_slug) > 20):
            raise ValueError("Invalid value for `name_slug`, length must be less than or equal to `20`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name_slug is not None and not re.search(r'^[a-z]|[a-z0-9][a-z0-9\-]*[a-z0-9]$', name_slug)):  # noqa: E501
            raise ValueError(r"Invalid value for `name_slug`, must be a follow pattern or equal to `/^[a-z]|[a-z0-9][a-z0-9\-]*[a-z0-9]$/`")  # noqa: E501

        self._name_slug = name_slug

    @property
    def org_id(self):
        """Gets the org_id of this AgentConnectorSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this AgentConnectorSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this AgentConnectorSpec.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this AgentConnectorSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def max_number_connections(self):
        """Gets the max_number_connections of this AgentConnectorSpec.  # noqa: E501

        The maximum number of connections to maintain to the cluster when stable. Note that this value may be exceeded during times of reconfiguration. A value of zero means that the connector is effectively unused by this Secure Agent.   # noqa: E501

        :return: The max_number_connections of this AgentConnectorSpec.  # noqa: E501
        :rtype: int
        """
        return self._max_number_connections

    @max_number_connections.setter
    def max_number_connections(self, max_number_connections):
        """Sets the max_number_connections of this AgentConnectorSpec.

        The maximum number of connections to maintain to the cluster when stable. Note that this value may be exceeded during times of reconfiguration. A value of zero means that the connector is effectively unused by this Secure Agent.   # noqa: E501

        :param max_number_connections: The max_number_connections of this AgentConnectorSpec.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_number_connections is not None and max_number_connections > 64):  # noqa: E501
            raise ValueError("Invalid value for `max_number_connections`, must be a value less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_number_connections is not None and max_number_connections < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_number_connections`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_number_connections = max_number_connections

    @property
    def connection_uri(self):
        """Gets the connection_uri of this AgentConnectorSpec.  # noqa: E501

        Overrides the default URI used to connect to this connector. This can be used to point the Secure Agent somewhere other than the default.   # noqa: E501

        :return: The connection_uri of this AgentConnectorSpec.  # noqa: E501
        :rtype: str
        """
        return self._connection_uri

    @connection_uri.setter
    def connection_uri(self, connection_uri):
        """Sets the connection_uri of this AgentConnectorSpec.

        Overrides the default URI used to connect to this connector. This can be used to point the Secure Agent somewhere other than the default.   # noqa: E501

        :param connection_uri: The connection_uri of this AgentConnectorSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                connection_uri is not None and len(connection_uri) > 1024):
            raise ValueError("Invalid value for `connection_uri`, length must be less than or equal to `1024`")  # noqa: E501

        self._connection_uri = connection_uri

    @property
    def service_account_required(self):
        """Gets the service_account_required of this AgentConnectorSpec.  # noqa: E501

        If service_account_enabled field is set to true, a service account will be created. If service_account_enabled field is set to false, the service account will be deleted. If the service_account_enabled field is not set no action on the service account is taken.   # noqa: E501

        :return: The service_account_required of this AgentConnectorSpec.  # noqa: E501
        :rtype: bool
        """
        return self._service_account_required

    @service_account_required.setter
    def service_account_required(self, service_account_required):
        """Sets the service_account_required of this AgentConnectorSpec.

        If service_account_enabled field is set to true, a service account will be created. If service_account_enabled field is set to false, the service account will be deleted. If the service_account_enabled field is not set no action on the service account is taken.   # noqa: E501

        :param service_account_required: The service_account_required of this AgentConnectorSpec.  # noqa: E501
        :type: bool
        """

        self._service_account_required = service_account_required

    @property
    def local_authentication_enabled(self):
        """Gets the local_authentication_enabled of this AgentConnectorSpec.  # noqa: E501

        Determines whether or not the agent will expose an endpoint for local authentication  # noqa: E501

        :return: The local_authentication_enabled of this AgentConnectorSpec.  # noqa: E501
        :rtype: bool
        """
        return self._local_authentication_enabled

    @local_authentication_enabled.setter
    def local_authentication_enabled(self, local_authentication_enabled):
        """Sets the local_authentication_enabled of this AgentConnectorSpec.

        Determines whether or not the agent will expose an endpoint for local authentication  # noqa: E501

        :param local_authentication_enabled: The local_authentication_enabled of this AgentConnectorSpec.  # noqa: E501
        :type: bool
        """

        self._local_authentication_enabled = local_authentication_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_access_requests_response import ListAccessRequestsResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListAccessRequestsResponse(unittest.TestCase):
    """ListAccessRequestsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListAccessRequestsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_access_requests_response.ListAccessRequestsResponse()  # noqa: E501
        if include_optional :
            return ListAccessRequestsResponse(
                access_requests = [
                    agilicus_api.models.access_requests.AccessRequests(
                        metadata = agilicus_api.models.metadata_with_only_id.MetadataWithOnlyId(
                            id = '123', ), 
                        status = agilicus_api.models.access_requests_status.AccessRequestsStatus(
                            user = {"id":"as3sdfl","first_name":"Example","last_name":"User","email":"user@example.com","type":"user"}, 
                            user_requests = [
                                agilicus_api.models.user_request_info.UserRequestInfo(
                                    spec = agilicus_api.models.user_request_info_spec.UserRequestInfoSpec(
                                        user_id = 'tuU7smH86zAXMl76sua6xQ', 
                                        org_id = 'IAsl3dl40aSsfLKiU76', 
                                        requested_resource = 'phone', 
                                        requested_sub_resource = 'self', 
                                        requested_resource_type = 'application_access', 
                                        request_information = 'I need this to do my job', 
                                        state = 'pending', ), )
                                ], ), )
                    ], 
                limit = 56, 
                previous_page_email = 'foo@example.com', 
                next_page_email = 'foo@example.com'
            )
        else :
            return ListAccessRequestsResponse(
                access_requests = [
                    agilicus_api.models.access_requests.AccessRequests(
                        metadata = agilicus_api.models.metadata_with_only_id.MetadataWithOnlyId(
                            id = '123', ), 
                        status = agilicus_api.models.access_requests_status.AccessRequestsStatus(
                            user = {"id":"as3sdfl","first_name":"Example","last_name":"User","email":"user@example.com","type":"user"}, 
                            user_requests = [
                                agilicus_api.models.user_request_info.UserRequestInfo(
                                    spec = agilicus_api.models.user_request_info_spec.UserRequestInfoSpec(
                                        user_id = 'tuU7smH86zAXMl76sua6xQ', 
                                        org_id = 'IAsl3dl40aSsfLKiU76', 
                                        requested_resource = 'phone', 
                                        requested_sub_resource = 'self', 
                                        requested_resource_type = 'application_access', 
                                        request_information = 'I need this to do my job', 
                                        state = 'pending', ), )
                                ], ), )
                    ],
                limit = 56,
        )

    def testListAccessRequestsResponse(self):
        """Test ListAccessRequestsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector import AgentConnector  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnector(unittest.TestCase):
    """AgentConnector unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnector
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector.AgentConnector()  # noqa: E501
        if include_optional :
            return AgentConnector(
                metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                spec = agilicus_api.models.agent_connector_spec.AgentConnectorSpec(
                    name = '0', 
                    name_slug = 'a', 
                    org_id = '123', 
                    max_number_connections = 0, 
                    connection_uri = '0', 
                    service_account_required = True, 
                    local_authentication_enabled = False, ), 
                status = agilicus_api.models.agent_connector_status.AgentConnectorStatus(
                    application_services = [
                        agilicus_api.models.application_service.ApplicationService(
                            created = '2015-07-07T15:49:51.230+02:00', 
                            id = '123', 
                            name = '0', 
                            org_id = '0', 
                            hostname = 'db.example.com', 
                            ipv4_addresses = [
                                '192.0.2.1'
                                ], 
                            name_resolution = 'static', 
                            port = 56, 
                            protocol = 'tcp', 
                            assignments = [
                                agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                    app_id = '0', 
                                    environment_name = '0', 
                                    org_id = '0', )
                                ], 
                            updated = '2015-07-07T15:49:51.230+02:00', 
                            service_type = 'vpn', 
                            service_protocol_type = 'ip', 
                            tls_enabled = True, 
                            tls_verify = True, 
                            connector_id = '123', 
                            connection_uri = '0', )
                        ], 
                    service_account_id = '0', 
                    info = agilicus_api.models.agent_connector_info.AgentConnectorInfo(
                        local_authentication_enabled = False, 
                        connections_info = [
                            agilicus_api.models.agent_connector_connection_info.AgentConnectorConnectionInfo(
                                connection_uri = 'wss://my-app.example.com/.agilcus-agent', 
                                connection_location = 'my-app.example.com', 
                                connection_path = '/.agilicus-agent', 
                                connection_org_id = 'asda93oidl2xZ6', 
                                connection_app_name = 'my-app', 
                                is_an_auth_service = True, 
                                end_to_end_tls = True, 
                                max_number_connections = 0, 
                                ip_services = [
                                    agilicus_api.models.application_service.ApplicationService(
                                        created = '2015-07-07T15:49:51.230+02:00', 
                                        id = '123', 
                                        name = '0', 
                                        org_id = '0', 
                                        hostname = 'db.example.com', 
                                        name_resolution = 'static', 
                                        port = 56, 
                                        protocol = 'tcp', 
                                        updated = '2015-07-07T15:49:51.230+02:00', 
                                        service_type = 'vpn', 
                                        service_protocol_type = 'ip', 
                                        tls_enabled = True, 
                                        tls_verify = True, 
                                        connector_id = '123', 
                                        connection_uri = '0', )
                                    ], 
                                file_share_services = [
                                    agilicus_api.models.file_share_service.FileShareService(
                                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                                        spec = agilicus_api.models.file_share_service_spec.FileShareServiceSpec(
                                            name = 'share1', 
                                            share_name = 'share1', 
                                            org_id = '123', 
                                            local_path = '/home/agilicus/public/share1', 
                                            connector_id = '123', 
                                            share_index = 1, 
                                            transport_end_to_end_tls = True, 
                                            transport_base_domain = '0', ), 
                                        status = agilicus_api.models.file_share_service_status.FileShareServiceStatus(
                                            share_base_app_name = '0', 
                                            instance_id = 'asdas9Gk4asdaTH', 
                                            instance_org_id = '39ddfGAaslts8qX', 
                                            share_uri = 'https://share-4.cloud.egov.city/', ), )
                                    ], 
                                application_config = agilicus_api.models.application_config.ApplicationConfig(
                                    authentication_config = agilicus_api.models.application_authentication_config.ApplicationAuthenticationConfig(
                                        application_handles_authentication = False, 
                                        session_secret = 'Gns5ZPCvXGjzrtB672HAxfoSQ0dmqriSgiQf6uEQSBU=', ), 
                                    oidc_config = agilicus_api.models.oidc_proxy_config.OIDCProxyConfig(
                                        headers = agilicus_api.models.oidc_proxy_header.OIDCProxyHeader(
                                            domain_substitution = agilicus_api.models.oidc_proxy_domain_substitution.OIDCProxyDomainSubstitution(
                                                standard_headers = agilicus_api.models.oidc_proxy_standard_header.OIDCProxyStandardHeader(
                                                    location = True, 
                                                    origin = True, 
                                                    host = True, ), 
                                                other_headers = [
                                                    agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                        name = 'Accept-Encoding', 
                                                        value = '*', )
                                                    ], ), 
                                            header_overrides = agilicus_api.models.oidc_proxy_header_override.OIDCProxyHeaderOverride(
                                                request = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(
                                                    set = [
                                                        agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                            name = 'Accept-Encoding', 
                                                            value = '*', )
                                                        ], 
                                                    add = [
                                                        agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                            name = 'Accept-Encoding', 
                                                            value = '*', )
                                                        ], 
                                                    remove = [
                                                        agilicus_api.models.oidc_proxy_header_name.OIDCProxyHeaderName(
                                                            name = '0', )
                                                        ], ), 
                                                response = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(), ), ), 
                                        domain_mapping = agilicus_api.models.oidc_proxy_domain_mapping.OIDCProxyDomainMapping(
                                            primary_external_name = 'app-1.cloud.egov.city', 
                                            primary_internal_name = 'app-1.internal', 
                                            other_mappings = [
                                                agilicus_api.models.oidc_proxy_domain_name_mapping.OIDCProxyDomainNameMapping(
                                                    internal_name = 'local_test_app', 
                                                    external_name = 'app-1', )
                                                ], ), 
                                        auth = agilicus_api.models.oidc_auth_config.OIDCAuthConfig(
                                            auth_enabled = True, 
                                            client_id = 'admin-portal', 
                                            issuer = 'https://auth.cloud.egov.city', 
                                            logout_url = '/login/logout.cfm', 
                                            scopes = [
                                                agilicus_api.models.oidc_proxy_scope.OIDCProxyScope(
                                                    name = 'urn:agilicus:app:app-1:owner', )
                                                ], 
                                            path_config = agilicus_api.models.oidc_auth_path_config.OIDCAuthPathConfig(
                                                included_paths = [{"path":"/login"}], 
                                                excluded_paths = [{"path":"/logout"}], ), ), 
                                        content_manipulation = agilicus_api.models.oidc_proxy_content_manipulation.OIDCProxyContentManipulation(
                                            media_types = [
                                                agilicus_api.models.oidc_content_type.OIDCContentType(
                                                    name = 'text/css', )
                                                ], ), 
                                        upstream_config = agilicus_api.models.oidc_proxy_upstream_config.OIDCProxyUpstreamConfig(
                                            scheme = 'https', 
                                            hostname = 'httpbin.org', ), ), ), )
                            ], 
                        allow_list = {
                            'key' : [
                                agilicus_api.models.allow_rule_compiled.AllowRuleCompiled(
                                    paths = [
                                        '/.*'
                                        ], 
                                    methods = ["get"], 
                                    any_auth_user = True, )
                                ]
                            }, 
                        authz_public_key = 'apublickey', 
                        application_service_uri = '0', 
                        tunnel_uri = 'wss://agent-server.ca-1.agilicus.ca/.agilicus-agent/control', 
                        service_forwarders = [
                            agilicus_api.models.service_forwarder.ServiceForwarder(
                                spec = agilicus_api.models.service_forwarder_spec.ServiceForwarderSpec(
                                    name = '0', 
                                    org_id = '0', 
                                    bind_address = 'localhost', 
                                    port = 56, 
                                    protocol = 'tcp', 
                                    application_service_id = '0', 
                                    connector_id = '123', ), )
                            ], 
                        from_service_forwarders = [
                            agilicus_api.models.service_forwarder.ServiceForwarder(
                                spec = agilicus_api.models.service_forwarder_spec.ServiceForwarderSpec(
                                    name = '0', 
                                    org_id = '0', 
                                    bind_address = 'localhost', 
                                    port = 56, 
                                    protocol = 'tcp', 
                                    application_service_id = '0', 
                                    connector_id = '123', ), )
                            ], ), 
                    stats = {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good","system":{"os_version":"5.4.0","os_uptime":15623,"agent_uptime":15000,"agent_version":"v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259","agent_connector_id":"as3asldlt3a","agent_connector_org_id":"dO04ldlfwe9a3l"},"transport":{"active_connections":5,"target_number_connections":5,"connection_start_count":10,"connection_stop_count":5}}, 
                    local_authentication = agilicus_api.models.agent_local_auth_info.AgentLocalAuthInfo(
                        org_id = '123', 
                        local_authentication_public_key = '-----BEGIN PRIVATE KEY-----\nActualKeyContents\n-----END PRIVATE KEY-----\n', ), )
            )
        else :
            return AgentConnector(
                spec = agilicus_api.models.agent_connector_spec.AgentConnectorSpec(
                    name = '0', 
                    name_slug = 'a', 
                    org_id = '123', 
                    max_number_connections = 0, 
                    connection_uri = '0', 
                    service_account_required = True, 
                    local_authentication_enabled = False, ),
        )

    def testAgentConnector(self):
        """Test AgentConnector"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.application_summary import ApplicationSummary  # noqa: E501
from agilicus_api.rest import ApiException

class TestApplicationSummary(unittest.TestCase):
    """ApplicationSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApplicationSummary
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.application_summary.ApplicationSummary()  # noqa: E501
        if include_optional :
            return ApplicationSummary(
                status = agilicus_api.models.application_summary_status.ApplicationSummaryStatus(
                    application_id = '39dl4dDJGdjgud8', 
                    application_name = 'parking', 
                    assigned_org_id = 'as9f9adfDFwEE9', 
                    published = 'no', 
                    description = 'An application to submit parking requests', 
                    category = 'citizen-facing', 
                    icon_url = 'https://storage.googleapis.com/agilicus/logo.svg', 
                    default_role_name = 'self', 
                    default_role_id = 'as0Z6fXFsl23', )
            )
        else :
            return ApplicationSummary(
                status = agilicus_api.models.application_summary_status.ApplicationSummaryStatus(
                    application_id = '39dl4dDJGdjgud8', 
                    application_name = 'parking', 
                    assigned_org_id = 'as9f9adfDFwEE9', 
                    published = 'no', 
                    description = 'An application to submit parking requests', 
                    category = 'citizen-facing', 
                    icon_url = 'https://storage.googleapis.com/agilicus/logo.svg', 
                    default_role_name = 'self', 
                    default_role_id = 'as0Z6fXFsl23', ),
        )

    def testApplicationSummary(self):
        """Test ApplicationSummary"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.environment import Environment  # noqa: E501
from agilicus_api.rest import ApiException

class TestEnvironment(unittest.TestCase):
    """Environment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Environment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.environment.Environment()  # noqa: E501
        if include_optional :
            return Environment(
                created = '2015-07-07T15:49:51.230+02:00', 
                name = '0', 
                maintenance_org_id = '0', 
                domain_aliases = [
                    'a'
                    ], 
                version_tag = '0', 
                config_mount_path = '0', 
                config_as_mount = '0', 
                config_as_env = '0', 
                secrets_mount_path = '0', 
                secrets_as_mount = '0', 
                secrets_as_env = '0', 
                application_services = [
                    agilicus_api.models.application_service.ApplicationService(
                        created = '2015-07-07T15:49:51.230+02:00', 
                        id = '123', 
                        name = '0', 
                        org_id = '0', 
                        hostname = 'db.example.com', 
                        ipv4_addresses = [
                            '192.0.2.1'
                            ], 
                        name_resolution = 'static', 
                        port = 56, 
                        protocol = 'tcp', 
                        assignments = [
                            agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                app_id = '0', 
                                environment_name = '0', 
                                org_id = '0', )
                            ], 
                        updated = '2015-07-07T15:49:51.230+02:00', 
                        service_type = 'vpn', 
                        service_protocol_type = 'ip', 
                        tls_enabled = True, 
                        tls_verify = True, 
                        connector_id = '123', 
                        connection_uri = '0', )
                    ], 
                serverless_image = '0', 
                status = agilicus_api.models.environment_status.EnvironmentStatus(
                    runtime_status = agilicus_api.models.runtime_status.RuntimeStatus(
                        overall_status = 'good', 
                        running_replicas = 2, 
                        error_message = 'CrashLoopBackoff', 
                        restarts = 5, 
                        cpu = 0.6, 
                        memory = 45.2, 
                        last_apply_time = '2002-10-02T10:00-05:00', 
                        updated = '2015-07-07T15:49:51.230+02:00', 
                        running_image = 'cr.agilicus.com/applications/iomad:v1.13.0', 
                        running_hash = 'sha256:2fb759c1adfe40863b89a4076111af8f210e7342d2240f09b08fc445b357112e', 
                        org_id = '123', ), ), 
                updated = '2015-07-07T15:49:51.230+02:00', 
                application_configs = agilicus_api.models.application_config.ApplicationConfig(
                    authentication_config = agilicus_api.models.application_authentication_config.ApplicationAuthenticationConfig(
                        application_handles_authentication = False, 
                        session_secret = 'Gns5ZPCvXGjzrtB672HAxfoSQ0dmqriSgiQf6uEQSBU=', ), 
                    oidc_config = agilicus_api.models.oidc_proxy_config.OIDCProxyConfig(
                        headers = agilicus_api.models.oidc_proxy_header.OIDCProxyHeader(
                            domain_substitution = agilicus_api.models.oidc_proxy_domain_substitution.OIDCProxyDomainSubstitution(
                                standard_headers = agilicus_api.models.oidc_proxy_standard_header.OIDCProxyStandardHeader(
                                    location = True, 
                                    origin = True, 
                                    host = True, ), 
                                other_headers = [
                                    agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                        name = 'Accept-Encoding', 
                                        value = '*', )
                                    ], ), 
                            header_overrides = agilicus_api.models.oidc_proxy_header_override.OIDCProxyHeaderOverride(
                                request = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(
                                    set = [
                                        agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                            name = 'Accept-Encoding', 
                                            value = '*', )
                                        ], 
                                    add = [
                                        agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                            name = 'Accept-Encoding', 
                                            value = '*', )
                                        ], 
                                    remove = [
                                        agilicus_api.models.oidc_proxy_header_name.OIDCProxyHeaderName(
                                            name = '0', )
                                        ], ), 
                                response = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(), ), ), 
                        domain_mapping = agilicus_api.models.oidc_proxy_domain_mapping.OIDCProxyDomainMapping(
                            primary_external_name = 'app-1.cloud.egov.city', 
                            primary_internal_name = 'app-1.internal', 
                            other_mappings = [
                                agilicus_api.models.oidc_proxy_domain_name_mapping.OIDCProxyDomainNameMapping(
                                    internal_name = 'local_test_app', 
                                    external_name = 'app-1', )
                                ], ), 
                        auth = agilicus_api.models.oidc_auth_config.OIDCAuthConfig(
                            auth_enabled = True, 
                            client_id = 'admin-portal', 
                            issuer = 'https://auth.cloud.egov.city', 
                            logout_url = '/login/logout.cfm', 
                            scopes = [
                                agilicus_api.models.oidc_proxy_scope.OIDCProxyScope(
                                    name = 'urn:agilicus:app:app-1:owner', )
                                ], 
                            path_config = agilicus_api.models.oidc_auth_path_config.OIDCAuthPathConfig(
                                included_paths = [{"path":"/login"}], 
                                excluded_paths = [{"path":"/logout"}], ), ), 
                        content_manipulation = agilicus_api.models.oidc_proxy_content_manipulation.OIDCProxyContentManipulation(
                            media_types = [
                                agilicus_api.models.oidc_content_type.OIDCContentType(
                                    name = 'text/css', )
                                ], ), 
                        upstream_config = agilicus_api.models.oidc_proxy_upstream_config.OIDCProxyUpstreamConfig(
                            scheme = 'https', 
                            hostname = 'httpbin.org', ), ), ), 
                name_slug = 'a', 
                proxy_location = 'in_cloud'
            )
        else :
            return Environment(
                name = '0',
        )

    def testEnvironment(self):
        """Test Environment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_authz_stats import AgentConnectorAuthzStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorAuthzStats(unittest.TestCase):
    """AgentConnectorAuthzStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorAuthzStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_authz_stats.AgentConnectorAuthzStats()  # noqa: E501
        if include_optional :
            return AgentConnectorAuthzStats(
                allowed = 32, 
                allowed_app_handled = 32, 
                denied = 32, 
                token_cached_failed = 64, 
                token_cached_success = 64, 
                token_parse_failed = 64, 
                token_static_token = 64, 
                token_bad_jti = 64, 
                token_lookup_success = 64, 
                token_lookup_notfound = 64, 
                token_lookup_badrequest = 64, 
                token_lookup_4xx_other = 64, 
                token_lookup_error = 64, 
                token_lookup_revoked = 64, 
                token_basic_auth_decode_fail = 64, 
                token_basic_auth_too_long = 64, 
                token_basic_auth_no_password = 64, 
                token_basic_auth_cached_success = 64, 
                token_basic_auth_cached_failed = 64
            )
        else :
            return AgentConnectorAuthzStats(
                allowed = 32,
                allowed_app_handled = 32,
                denied = 32,
                token_cached_failed = 64,
                token_cached_success = 64,
                token_parse_failed = 64,
                token_static_token = 64,
                token_bad_jti = 64,
                token_lookup_success = 64,
                token_lookup_notfound = 64,
                token_lookup_badrequest = 64,
                token_lookup_4xx_other = 64,
                token_lookup_error = 64,
                token_lookup_revoked = 64,
                token_basic_auth_decode_fail = 64,
                token_basic_auth_too_long = 64,
                token_basic_auth_no_password = 64,
                token_basic_auth_cached_success = 64,
                token_basic_auth_cached_failed = 64,
        )

    def testAgentConnectorAuthzStats(self):
        """Test AgentConnectorAuthzStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class APIKeyIntrospect(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_key_auth_info': 'APIKeyIntrospectAuthorizationInfo',
        'introspect_options': 'TokenIntrospectOptions',
        'multi_org': 'bool'
    }

    attribute_map = {
        'api_key_auth_info': 'api_key_auth_info',
        'introspect_options': 'introspect_options',
        'multi_org': 'multi_org'
    }

    def __init__(self, api_key_auth_info=None, introspect_options=None, multi_org=None, local_vars_configuration=None):  # noqa: E501
        """APIKeyIntrospect - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._api_key_auth_info = None
        self._introspect_options = None
        self._multi_org = None
        self.discriminator = None

        self.api_key_auth_info = api_key_auth_info
        if introspect_options is not None:
            self.introspect_options = introspect_options
        if multi_org is not None:
            self.multi_org = multi_org

    @property
    def api_key_auth_info(self):
        """Gets the api_key_auth_info of this APIKeyIntrospect.  # noqa: E501


        :return: The api_key_auth_info of this APIKeyIntrospect.  # noqa: E501
        :rtype: APIKeyIntrospectAuthorizationInfo
        """
        return self._api_key_auth_info

    @api_key_auth_info.setter
    def api_key_auth_info(self, api_key_auth_info):
        """Sets the api_key_auth_info of this APIKeyIntrospect.


        :param api_key_auth_info: The api_key_auth_info of this APIKeyIntrospect.  # noqa: E501
        :type: APIKeyIntrospectAuthorizationInfo
        """
        if self.local_vars_configuration.client_side_validation and api_key_auth_info is None:  # noqa: E501
            raise ValueError("Invalid value for `api_key_auth_info`, must not be `None`")  # noqa: E501

        self._api_key_auth_info = api_key_auth_info

    @property
    def introspect_options(self):
        """Gets the introspect_options of this APIKeyIntrospect.  # noqa: E501


        :return: The introspect_options of this APIKeyIntrospect.  # noqa: E501
        :rtype: TokenIntrospectOptions
        """
        return self._introspect_options

    @introspect_options.setter
    def introspect_options(self, introspect_options):
        """Sets the introspect_options of this APIKeyIntrospect.


        :param introspect_options: The introspect_options of this APIKeyIntrospect.  # noqa: E501
        :type: TokenIntrospectOptions
        """

        self._introspect_options = introspect_options

    @property
    def multi_org(self):
        """Gets the multi_org of this APIKeyIntrospect.  # noqa: E501

        Whether or not to allow this APIKey to represent multiple orgs  # noqa: E501

        :return: The multi_org of this APIKeyIntrospect.  # noqa: E501
        :rtype: bool
        """
        return self._multi_org

    @multi_org.setter
    def multi_org(self, multi_org):
        """Sets the multi_org of this APIKeyIntrospect.

        Whether or not to allow this APIKey to represent multiple orgs  # noqa: E501

        :param multi_org: The multi_org of this APIKeyIntrospect.  # noqa: E501
        :type: bool
        """

        self._multi_org = multi_org

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, APIKeyIntrospect):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, APIKeyIntrospect):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import


# import apis into sdk package
from agilicus_api.api.application_services_api import ApplicationServicesApi
from agilicus_api.api.applications_api import ApplicationsApi
from agilicus_api.api.audits_api import AuditsApi
from agilicus_api.api.catalogues_api import CataloguesApi
from agilicus_api.api.certificates_api import CertificatesApi
from agilicus_api.api.challenges_api import ChallengesApi
from agilicus_api.api.connectors_api import ConnectorsApi
from agilicus_api.api.diagnostics_api import DiagnosticsApi
from agilicus_api.api.files_api import FilesApi
from agilicus_api.api.groups_api import GroupsApi
from agilicus_api.api.issuers_api import IssuersApi
from agilicus_api.api.messages_api import MessagesApi
from agilicus_api.api.metrics_api import MetricsApi
from agilicus_api.api.organisations_api import OrganisationsApi
from agilicus_api.api.permissions_api import PermissionsApi
from agilicus_api.api.policy_api import PolicyApi
from agilicus_api.api.services_api import ServicesApi
from agilicus_api.api.tokens_api import TokensApi
from agilicus_api.api.users_api import UsersApi
from agilicus_api.api.whoami_api import WhoamiApi

# import ApiClient
from agilicus_api.api_client import ApiClient
from agilicus_api.configuration import Configuration
from agilicus_api.exceptions import OpenApiException
from agilicus_api.exceptions import ApiTypeError
from agilicus_api.exceptions import ApiValueError
from agilicus_api.exceptions import ApiKeyError
from agilicus_api.exceptions import ApiException
# import models into sdk package
from agilicus_api.models.api_key import APIKey
from agilicus_api.models.api_key_introspect import APIKeyIntrospect
from agilicus_api.models.api_key_introspect_authorization_info import APIKeyIntrospectAuthorizationInfo
from agilicus_api.models.api_key_introspect_response import APIKeyIntrospectResponse
from agilicus_api.models.api_key_spec import APIKeySpec
from agilicus_api.models.api_key_status import APIKeyStatus
from agilicus_api.models.access_requests import AccessRequests
from agilicus_api.models.access_requests_status import AccessRequestsStatus
from agilicus_api.models.add_group_member_request import AddGroupMemberRequest
from agilicus_api.models.agent_connector import AgentConnector
from agilicus_api.models.agent_connector_authz_stats import AgentConnectorAuthzStats
from agilicus_api.models.agent_connector_connection_info import AgentConnectorConnectionInfo
from agilicus_api.models.agent_connector_info import AgentConnectorInfo
from agilicus_api.models.agent_connector_per_share_stats import AgentConnectorPerShareStats
from agilicus_api.models.agent_connector_proxy_request_stats import AgentConnectorProxyRequestStats
from agilicus_api.models.agent_connector_proxy_request_stats_details import AgentConnectorProxyRequestStatsDetails
from agilicus_api.models.agent_connector_proxy_stats import AgentConnectorProxyStats
from agilicus_api.models.agent_connector_share_stats import AgentConnectorShareStats
from agilicus_api.models.agent_connector_spec import AgentConnectorSpec
from agilicus_api.models.agent_connector_specific_stats import AgentConnectorSpecificStats
from agilicus_api.models.agent_connector_stats import AgentConnectorStats
from agilicus_api.models.agent_connector_status import AgentConnectorStatus
from agilicus_api.models.agent_connector_system_stats import AgentConnectorSystemStats
from agilicus_api.models.agent_connector_transport_stats import AgentConnectorTransportStats
from agilicus_api.models.agent_local_auth_info import AgentLocalAuthInfo
from agilicus_api.models.allow_map_compiled import AllowMapCompiled
from agilicus_api.models.allow_rule_compiled import AllowRuleCompiled
from agilicus_api.models.application import Application
from agilicus_api.models.application_assignment import ApplicationAssignment
from agilicus_api.models.application_authentication_config import ApplicationAuthenticationConfig
from agilicus_api.models.application_config import ApplicationConfig
from agilicus_api.models.application_monitoring_config import ApplicationMonitoringConfig
from agilicus_api.models.application_service import ApplicationService
from agilicus_api.models.application_service_assignment import ApplicationServiceAssignment
from agilicus_api.models.application_summary import ApplicationSummary
from agilicus_api.models.application_summary_status import ApplicationSummaryStatus
from agilicus_api.models.audit import Audit
from agilicus_api.models.auth_audits import AuthAudits
from agilicus_api.models.authentication_attribute import AuthenticationAttribute
from agilicus_api.models.authentication_document import AuthenticationDocument
from agilicus_api.models.authentication_document_spec import AuthenticationDocumentSpec
from agilicus_api.models.authentication_document_status import AuthenticationDocumentStatus
from agilicus_api.models.auto_create_status import AutoCreateStatus
from agilicus_api.models.base_upstream import BaseUpstream
from agilicus_api.models.base_upstreams import BaseUpstreams
from agilicus_api.models.bulk_session_operation_response import BulkSessionOperationResponse
from agilicus_api.models.bulk_token_revoke import BulkTokenRevoke
from agilicus_api.models.bulk_token_revoke_response import BulkTokenRevokeResponse
from agilicus_api.models.bulk_user_metadata import BulkUserMetadata
from agilicus_api.models.csr_reason_enum import CSRReasonEnum
from agilicus_api.models.catalogue import Catalogue
from agilicus_api.models.catalogue_entry import CatalogueEntry
from agilicus_api.models.cert_signing_req import CertSigningReq
from agilicus_api.models.cert_signing_req_spec import CertSigningReqSpec
from agilicus_api.models.cert_signing_req_status import CertSigningReqStatus
from agilicus_api.models.challenge import Challenge
from agilicus_api.models.challenge_answer import ChallengeAnswer
from agilicus_api.models.challenge_answer_spec import ChallengeAnswerSpec
from agilicus_api.models.challenge_endpoint import ChallengeEndpoint
from agilicus_api.models.challenge_spec import ChallengeSpec
from agilicus_api.models.challenge_status import ChallengeStatus
from agilicus_api.models.cipher_diffie_hellman_group import CipherDiffieHellmanGroup
from agilicus_api.models.cipher_encryption_algorithm import CipherEncryptionAlgorithm
from agilicus_api.models.cipher_integrity_algorithm import CipherIntegrityAlgorithm
from agilicus_api.models.combined_rules import CombinedRules
from agilicus_api.models.combined_rules_status import CombinedRulesStatus
from agilicus_api.models.combined_user_detail import CombinedUserDetail
from agilicus_api.models.combined_user_detail_status import CombinedUserDetailStatus
from agilicus_api.models.common_metadata import CommonMetadata
from agilicus_api.models.connector import Connector
from agilicus_api.models.connector_spec import ConnectorSpec
from agilicus_api.models.connector_stats import ConnectorStats
from agilicus_api.models.connector_stats_metadata import ConnectorStatsMetadata
from agilicus_api.models.connector_status import ConnectorStatus
from agilicus_api.models.create_session_and_token_request import CreateSessionAndTokenRequest
from agilicus_api.models.create_session_and_token_response import CreateSessionAndTokenResponse
from agilicus_api.models.create_token_request import CreateTokenRequest
from agilicus_api.models.definition import Definition
from agilicus_api.models.environment import Environment
from agilicus_api.models.environment_config import EnvironmentConfig
from agilicus_api.models.environment_config_var import EnvironmentConfigVar
from agilicus_api.models.environment_status import EnvironmentStatus
from agilicus_api.models.error_message import ErrorMessage
from agilicus_api.models.feature_flag import FeatureFlag
from agilicus_api.models.file import File
from agilicus_api.models.file_share_service import FileShareService
from agilicus_api.models.file_share_service_spec import FileShareServiceSpec
from agilicus_api.models.file_share_service_status import FileShareServiceStatus
from agilicus_api.models.file_summary import FileSummary
from agilicus_api.models.file_upload import FileUpload
from agilicus_api.models.file_visibility import FileVisibility
from agilicus_api.models.group import Group
from agilicus_api.models.group_data import GroupData
from agilicus_api.models.group_member import GroupMember
from agilicus_api.models.host_permissions import HostPermissions
from agilicus_api.models.http_rule import HttpRule
from agilicus_api.models.identity_assertion import IdentityAssertion
from agilicus_api.models.identity_assertion_response import IdentityAssertionResponse
from agilicus_api.models.included_role import IncludedRole
from agilicus_api.models.ipsec_connection import IpsecConnection
from agilicus_api.models.ipsec_connection_ipv4_block import IpsecConnectionIpv4Block
from agilicus_api.models.ipsec_connection_spec import IpsecConnectionSpec
from agilicus_api.models.ipsec_connector import IpsecConnector
from agilicus_api.models.ipsec_connector_spec import IpsecConnectorSpec
from agilicus_api.models.ipsec_connector_status import IpsecConnectorStatus
from agilicus_api.models.ipsec_gateway_interface import IpsecGatewayInterface
from agilicus_api.models.issuer import Issuer
from agilicus_api.models.issuer_client import IssuerClient
from agilicus_api.models.json_body_constraint import JSONBodyConstraint
from agilicus_api.models.list_api_keys_response import ListAPIKeysResponse
from agilicus_api.models.list_access_requests_response import ListAccessRequestsResponse
from agilicus_api.models.list_active_users_response import ListActiveUsersResponse
from agilicus_api.models.list_agent_connector_response import ListAgentConnectorResponse
from agilicus_api.models.list_application_services_response import ListApplicationServicesResponse
from agilicus_api.models.list_application_summary_response import ListApplicationSummaryResponse
from agilicus_api.models.list_applications_response import ListApplicationsResponse
from agilicus_api.models.list_audits_response import ListAuditsResponse
from agilicus_api.models.list_auth_audits_response import ListAuthAuditsResponse
from agilicus_api.models.list_authentication_document_response import ListAuthenticationDocumentResponse
from agilicus_api.models.list_catalogue_entries_response import ListCatalogueEntriesResponse
from agilicus_api.models.list_catalogues_response import ListCataloguesResponse
from agilicus_api.models.list_cert_signing_req_response import ListCertSigningReqResponse
from agilicus_api.models.list_combined_rules_response import ListCombinedRulesResponse
from agilicus_api.models.list_combined_user_details_response import ListCombinedUserDetailsResponse
from agilicus_api.models.list_configs_response import ListConfigsResponse
from agilicus_api.models.list_connector_response import ListConnectorResponse
from agilicus_api.models.list_elevated_user_roles import ListElevatedUserRoles
from agilicus_api.models.list_environment_configs_response import ListEnvironmentConfigsResponse
from agilicus_api.models.list_file_share_services_response import ListFileShareServicesResponse
from agilicus_api.models.list_files_response import ListFilesResponse
from agilicus_api.models.list_groups_response import ListGroupsResponse
from agilicus_api.models.list_ipsec_connector_response import ListIpsecConnectorResponse
from agilicus_api.models.list_issuer_clients_response import ListIssuerClientsResponse
from agilicus_api.models.list_issuer_extensions_response import ListIssuerExtensionsResponse
from agilicus_api.models.list_issuer_roots_response import ListIssuerRootsResponse
from agilicus_api.models.list_logs_response import ListLogsResponse
from agilicus_api.models.list_mfa_challenge_methods import ListMFAChallengeMethods
from agilicus_api.models.list_message_endpoints_response import ListMessageEndpointsResponse
from agilicus_api.models.list_orgs_response import ListOrgsResponse
from agilicus_api.models.list_policies_response import ListPoliciesResponse
from agilicus_api.models.list_policy_rules_response import ListPolicyRulesResponse
from agilicus_api.models.list_resource_permissions_response import ListResourcePermissionsResponse
from agilicus_api.models.list_resource_roles_response import ListResourceRolesResponse
from agilicus_api.models.list_role_to_rule_entries import ListRoleToRuleEntries
from agilicus_api.models.list_roles import ListRoles
from agilicus_api.models.list_rules import ListRules
from agilicus_api.models.list_secure_agent_response import ListSecureAgentResponse
from agilicus_api.models.list_service_account_response import ListServiceAccountResponse
from agilicus_api.models.list_service_forwarders_response import ListServiceForwardersResponse
from agilicus_api.models.list_services_response import ListServicesResponse
from agilicus_api.models.list_sessions_response import ListSessionsResponse
from agilicus_api.models.list_totp_enrollment_response import ListTOTPEnrollmentResponse
from agilicus_api.models.list_tokens_response import ListTokensResponse
from agilicus_api.models.list_top_users_response import ListTopUsersResponse
from agilicus_api.models.list_upstream_user_identities_response import ListUpstreamUserIdentitiesResponse
from agilicus_api.models.list_user_application_access_info_response import ListUserApplicationAccessInfoResponse
from agilicus_api.models.list_user_file_share_access_info_response import ListUserFileShareAccessInfoResponse
from agilicus_api.models.list_user_guids_response import ListUserGuidsResponse
from agilicus_api.models.list_user_metadata_response import ListUserMetadataResponse
from agilicus_api.models.list_user_request_info_response import ListUserRequestInfoResponse
from agilicus_api.models.list_user_roles_for_an_org import ListUserRolesForAnOrg
from agilicus_api.models.list_users_response import ListUsersResponse
from agilicus_api.models.list_web_auth_n_enrollment_response import ListWebAuthNEnrollmentResponse
from agilicus_api.models.list_well_known_issuer_info import ListWellKnownIssuerInfo
from agilicus_api.models.list_x509_certificate_response import ListX509CertificateResponse
from agilicus_api.models.local_auth_upstream_config import LocalAuthUpstreamConfig
from agilicus_api.models.local_auth_upstream_identity_provider import LocalAuthUpstreamIdentityProvider
from agilicus_api.models.log import Log
from agilicus_api.models.login_session import LoginSession
from agilicus_api.models.mfa_challenge_answer import MFAChallengeAnswer
from agilicus_api.models.mfa_challenge_answer_result import MFAChallengeAnswerResult
from agilicus_api.models.mfa_challenge_method import MFAChallengeMethod
from agilicus_api.models.mfa_challenge_method_spec import MFAChallengeMethodSpec
from agilicus_api.models.mfa_challenge_question import MFAChallengeQuestion
from agilicus_api.models.mfa_challenge_question_input import MFAChallengeQuestionInput
from agilicus_api.models.mfa_challenge_question_login_info import MFAChallengeQuestionLoginInfo
from agilicus_api.models.mfa_enrollment_answer import MFAEnrollmentAnswer
from agilicus_api.models.mfa_enrollment_answer_result import MFAEnrollmentAnswerResult
from agilicus_api.models.mfa_enrollment_question import MFAEnrollmentQuestion
from agilicus_api.models.mfa_enrollment_question_input import MFAEnrollmentQuestionInput
from agilicus_api.models.mfa_enrollment_question_login_info import MFAEnrollmentQuestionLoginInfo
from agilicus_api.models.managed_upstream_identity_provider import ManagedUpstreamIdentityProvider
from agilicus_api.models.many_org_token_introspect_response import ManyOrgTokenIntrospectResponse
from agilicus_api.models.map_attributes_answer import MapAttributesAnswer
from agilicus_api.models.map_attributes_answer_result import MapAttributesAnswerResult
from agilicus_api.models.map_attributes_question import MapAttributesQuestion
from agilicus_api.models.map_attributes_question_input import MapAttributesQuestionInput
from agilicus_api.models.map_attributes_question_login_info import MapAttributesQuestionLoginInfo
from agilicus_api.models.mapped_attributes import MappedAttributes
from agilicus_api.models.message import Message
from agilicus_api.models.message_action import MessageAction
from agilicus_api.models.message_endpoint import MessageEndpoint
from agilicus_api.models.message_endpoint_metadata import MessageEndpointMetadata
from agilicus_api.models.message_endpoint_spec import MessageEndpointSpec
from agilicus_api.models.message_endpoint_type import MessageEndpointType
from agilicus_api.models.message_endpoint_type_web_push import MessageEndpointTypeWebPush
from agilicus_api.models.message_endpoints_config import MessageEndpointsConfig
from agilicus_api.models.metadata_with_id import MetadataWithId
from agilicus_api.models.metadata_with_id_all_of import MetadataWithIdAllOf
from agilicus_api.models.metadata_with_only_id import MetadataWithOnlyId
from agilicus_api.models.oidc_auth_config import OIDCAuthConfig
from agilicus_api.models.oidc_auth_path_config import OIDCAuthPathConfig
from agilicus_api.models.oidc_auth_uri import OIDCAuthURI
from agilicus_api.models.oidc_content_type import OIDCContentType
from agilicus_api.models.oidc_proxy_config import OIDCProxyConfig
from agilicus_api.models.oidc_proxy_content_manipulation import OIDCProxyContentManipulation
from agilicus_api.models.oidc_proxy_domain_mapping import OIDCProxyDomainMapping
from agilicus_api.models.oidc_proxy_domain_name_mapping import OIDCProxyDomainNameMapping
from agilicus_api.models.oidc_proxy_domain_substitution import OIDCProxyDomainSubstitution
from agilicus_api.models.oidc_proxy_header import OIDCProxyHeader
from agilicus_api.models.oidc_proxy_header_mapping import OIDCProxyHeaderMapping
from agilicus_api.models.oidc_proxy_header_name import OIDCProxyHeaderName
from agilicus_api.models.oidc_proxy_header_override import OIDCProxyHeaderOverride
from agilicus_api.models.oidc_proxy_header_user_config import OIDCProxyHeaderUserConfig
from agilicus_api.models.oidc_proxy_scope import OIDCProxyScope
from agilicus_api.models.oidc_proxy_standard_header import OIDCProxyStandardHeader
from agilicus_api.models.oidc_proxy_upstream_config import OIDCProxyUpstreamConfig
from agilicus_api.models.oidc_upstream_identity_provider import OIDCUpstreamIdentityProvider
from agilicus_api.models.organisation import Organisation
from agilicus_api.models.organisation_admin import OrganisationAdmin
from agilicus_api.models.organisation_state_selector import OrganisationStateSelector
from agilicus_api.models.organisation_state_status import OrganisationStateStatus
from agilicus_api.models.organisation_status import OrganisationStatus
from agilicus_api.models.policy import Policy
from agilicus_api.models.policy_condition import PolicyCondition
from agilicus_api.models.policy_group import PolicyGroup
from agilicus_api.models.policy_group_spec import PolicyGroupSpec
from agilicus_api.models.policy_rule import PolicyRule
from agilicus_api.models.policy_rule_spec import PolicyRuleSpec
from agilicus_api.models.policy_spec import PolicySpec
from agilicus_api.models.raw_token import RawToken
from agilicus_api.models.rendered_query_parameter import RenderedQueryParameter
from agilicus_api.models.rendered_resource_permissions import RenderedResourcePermissions
from agilicus_api.models.rendered_rule import RenderedRule
from agilicus_api.models.rendered_rule_body import RenderedRuleBody
from agilicus_api.models.replace_user_role_request import ReplaceUserRoleRequest
from agilicus_api.models.reset_mfa_challenge_method import ResetMFAChallengeMethod
from agilicus_api.models.reset_policy_request import ResetPolicyRequest
from agilicus_api.models.resource_permission import ResourcePermission
from agilicus_api.models.resource_permission_spec import ResourcePermissionSpec
from agilicus_api.models.resource_role import ResourceRole
from agilicus_api.models.resource_role_spec import ResourceRoleSpec
from agilicus_api.models.role import Role
from agilicus_api.models.role_list import RoleList
from agilicus_api.models.role_spec import RoleSpec
from agilicus_api.models.role_to_rule_entry import RoleToRuleEntry
from agilicus_api.models.role_to_rule_entry_spec import RoleToRuleEntrySpec
from agilicus_api.models.role_v2 import RoleV2
from agilicus_api.models.roles import Roles
from agilicus_api.models.rule import Rule
from agilicus_api.models.rule_query_body import RuleQueryBody
from agilicus_api.models.rule_query_body_json import RuleQueryBodyJSON
from agilicus_api.models.rule_query_parameter import RuleQueryParameter
from agilicus_api.models.rule_scope_enum import RuleScopeEnum
from agilicus_api.models.rule_spec import RuleSpec
from agilicus_api.models.rule_v2 import RuleV2
from agilicus_api.models.runtime_status import RuntimeStatus
from agilicus_api.models.secure_agent import SecureAgent
from agilicus_api.models.secure_agent_connector import SecureAgentConnector
from agilicus_api.models.secure_agent_connector_info import SecureAgentConnectorInfo
from agilicus_api.models.secure_agent_spec import SecureAgentSpec
from agilicus_api.models.secure_agent_status import SecureAgentStatus
from agilicus_api.models.service import Service
from agilicus_api.models.service_account import ServiceAccount
from agilicus_api.models.service_account_spec import ServiceAccountSpec
from agilicus_api.models.service_account_status import ServiceAccountStatus
from agilicus_api.models.service_forwarder import ServiceForwarder
from agilicus_api.models.service_forwarder_spec import ServiceForwarderSpec
from agilicus_api.models.service_forwarder_status import ServiceForwarderStatus
from agilicus_api.models.session import Session
from agilicus_api.models.sessions_spec import SessionsSpec
from agilicus_api.models.storage_region import StorageRegion
from agilicus_api.models.totp_enrollment import TOTPEnrollment
from agilicus_api.models.totp_enrollment_answer import TOTPEnrollmentAnswer
from agilicus_api.models.totp_enrollment_spec import TOTPEnrollmentSpec
from agilicus_api.models.totp_enrollment_status import TOTPEnrollmentStatus
from agilicus_api.models.time_interval_metrics import TimeIntervalMetrics
from agilicus_api.models.time_validity import TimeValidity
from agilicus_api.models.token import Token
from agilicus_api.models.token_introspect import TokenIntrospect
from agilicus_api.models.token_introspect_options import TokenIntrospectOptions
from agilicus_api.models.token_reissue_request import TokenReissueRequest
from agilicus_api.models.token_revoke import TokenRevoke
from agilicus_api.models.token_validity import TokenValidity
from agilicus_api.models.upstream_user_identity import UpstreamUserIdentity
from agilicus_api.models.upstream_user_identity_spec import UpstreamUserIdentitySpec
from agilicus_api.models.user import User
from agilicus_api.models.user_application_access_info import UserApplicationAccessInfo
from agilicus_api.models.user_application_access_info_status import UserApplicationAccessInfoStatus
from agilicus_api.models.user_file_share_access_info import UserFileShareAccessInfo
from agilicus_api.models.user_file_share_access_info_status import UserFileShareAccessInfoStatus
from agilicus_api.models.user_identity import UserIdentity
from agilicus_api.models.user_identity_update import UserIdentityUpdate
from agilicus_api.models.user_identity_update_spec import UserIdentityUpdateSpec
from agilicus_api.models.user_info import UserInfo
from agilicus_api.models.user_member_of import UserMemberOf
from agilicus_api.models.user_metadata import UserMetadata
from agilicus_api.models.user_metadata_spec import UserMetadataSpec
from agilicus_api.models.user_metrics import UserMetrics
from agilicus_api.models.user_request_info import UserRequestInfo
from agilicus_api.models.user_request_info_spec import UserRequestInfoSpec
from agilicus_api.models.user_request_info_status import UserRequestInfoStatus
from agilicus_api.models.user_roles import UserRoles
from agilicus_api.models.user_roles_for_an_org import UserRolesForAnOrg
from agilicus_api.models.user_session_identifiers import UserSessionIdentifiers
from agilicus_api.models.user_status_enum import UserStatusEnum
from agilicus_api.models.user_summary import UserSummary
from agilicus_api.models.web_auth_n_enrollment import WebAuthNEnrollment
from agilicus_api.models.web_auth_n_enrollment_answer import WebAuthNEnrollmentAnswer
from agilicus_api.models.web_auth_n_enrollment_spec import WebAuthNEnrollmentSpec
from agilicus_api.models.web_auth_n_enrollment_status import WebAuthNEnrollmentStatus
from agilicus_api.models.well_known_issuer_info import WellKnownIssuerInfo
from agilicus_api.models.whoami_request import WhoamiRequest
from agilicus_api.models.whoami_response import WhoamiResponse
from agilicus_api.models.x509_certificate import X509Certificate
from agilicus_api.models.x509_certificate_spec import X509CertificateSpec
from agilicus_api.models.x509_certificate_status import X509CertificateStatus




# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AuthAudits(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'upstream_user_id': 'str',
        'org_id': 'str',
        'org_name': 'str',
        'time': 'datetime',
        'event': 'str',
        'source_ip': 'str',
        'token_id': 'str',
        'trace_id': 'str',
        'session': 'str',
        'issuer': 'str',
        'client_id': 'str',
        'application_name': 'str',
        'login_org_id': 'str',
        'login_org_name': 'str',
        'upstream_idp': 'str',
        'stage': 'str',
        'user_agent': 'str'
    }

    attribute_map = {
        'user_id': 'user_id',
        'upstream_user_id': 'upstream_user_id',
        'org_id': 'org_id',
        'org_name': 'org_name',
        'time': 'time',
        'event': 'event',
        'source_ip': 'source_ip',
        'token_id': 'token_id',
        'trace_id': 'trace_id',
        'session': 'session',
        'issuer': 'issuer',
        'client_id': 'client_id',
        'application_name': 'application_name',
        'login_org_id': 'login_org_id',
        'login_org_name': 'login_org_name',
        'upstream_idp': 'upstream_idp',
        'stage': 'stage',
        'user_agent': 'user_agent'
    }

    def __init__(self, user_id=None, upstream_user_id=None, org_id=None, org_name=None, time=None, event=None, source_ip=None, token_id=None, trace_id=None, session=None, issuer=None, client_id=None, application_name=None, login_org_id=None, login_org_name=None, upstream_idp=None, stage=None, user_agent=None, local_vars_configuration=None):  # noqa: E501
        """AuthAudits - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._upstream_user_id = None
        self._org_id = None
        self._org_name = None
        self._time = None
        self._event = None
        self._source_ip = None
        self._token_id = None
        self._trace_id = None
        self._session = None
        self._issuer = None
        self._client_id = None
        self._application_name = None
        self._login_org_id = None
        self._login_org_name = None
        self._upstream_idp = None
        self._stage = None
        self._user_agent = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if upstream_user_id is not None:
            self.upstream_user_id = upstream_user_id
        if org_id is not None:
            self.org_id = org_id
        if org_name is not None:
            self.org_name = org_name
        if time is not None:
            self.time = time
        if event is not None:
            self.event = event
        if source_ip is not None:
            self.source_ip = source_ip
        if token_id is not None:
            self.token_id = token_id
        if trace_id is not None:
            self.trace_id = trace_id
        if session is not None:
            self.session = session
        if issuer is not None:
            self.issuer = issuer
        if client_id is not None:
            self.client_id = client_id
        if application_name is not None:
            self.application_name = application_name
        if login_org_id is not None:
            self.login_org_id = login_org_id
        if login_org_name is not None:
            self.login_org_name = login_org_name
        if upstream_idp is not None:
            self.upstream_idp = upstream_idp
        if stage is not None:
            self.stage = stage
        if user_agent is not None:
            self.user_agent = user_agent

    @property
    def user_id(self):
        """Gets the user_id of this AuthAudits.  # noqa: E501

        The system-local id of the user performing the action.  # noqa: E501

        :return: The user_id of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AuthAudits.

        The system-local id of the user performing the action.  # noqa: E501

        :param user_id: The user_id of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def upstream_user_id(self):
        """Gets the upstream_user_id of this AuthAudits.  # noqa: E501

        The id of the user in the upstream system, if available.  # noqa: E501

        :return: The upstream_user_id of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._upstream_user_id

    @upstream_user_id.setter
    def upstream_user_id(self, upstream_user_id):
        """Sets the upstream_user_id of this AuthAudits.

        The id of the user in the upstream system, if available.  # noqa: E501

        :param upstream_user_id: The upstream_user_id of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._upstream_user_id = upstream_user_id

    @property
    def org_id(self):
        """Gets the org_id of this AuthAudits.  # noqa: E501

        The id of the organisation of the issuer against which the user is authenticating.   # noqa: E501

        :return: The org_id of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this AuthAudits.

        The id of the organisation of the issuer against which the user is authenticating.   # noqa: E501

        :param org_id: The org_id of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._org_id = org_id

    @property
    def org_name(self):
        """Gets the org_name of this AuthAudits.  # noqa: E501

        The name of the organisation of the issuer against which the user is authenticating.   # noqa: E501

        :return: The org_name of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._org_name

    @org_name.setter
    def org_name(self, org_name):
        """Sets the org_name of this AuthAudits.

        The name of the organisation of the issuer against which the user is authenticating.   # noqa: E501

        :param org_name: The org_name of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._org_name = org_name

    @property
    def time(self):
        """Gets the time of this AuthAudits.  # noqa: E501

        the time at which the record was generated.  # noqa: E501

        :return: The time of this AuthAudits.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this AuthAudits.

        the time at which the record was generated.  # noqa: E501

        :param time: The time of this AuthAudits.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def event(self):
        """Gets the event of this AuthAudits.  # noqa: E501

        The event which generated the record. The meaning of the event depends on the stage where it occured.   # noqa: E501

        :return: The event of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this AuthAudits.

        The event which generated the record. The meaning of the event depends on the stage where it occured.   # noqa: E501

        :param event: The event of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._event = event

    @property
    def source_ip(self):
        """Gets the source_ip of this AuthAudits.  # noqa: E501

        The IP address of the host initiating the action  # noqa: E501

        :return: The source_ip of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._source_ip

    @source_ip.setter
    def source_ip(self, source_ip):
        """Sets the source_ip of this AuthAudits.

        The IP address of the host initiating the action  # noqa: E501

        :param source_ip: The source_ip of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._source_ip = source_ip

    @property
    def token_id(self):
        """Gets the token_id of this AuthAudits.  # noqa: E501

        The id of the token issued or reissued as part of the authentication.  # noqa: E501

        :return: The token_id of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._token_id

    @token_id.setter
    def token_id(self, token_id):
        """Sets the token_id of this AuthAudits.

        The id of the token issued or reissued as part of the authentication.  # noqa: E501

        :param token_id: The token_id of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._token_id = token_id

    @property
    def trace_id(self):
        """Gets the trace_id of this AuthAudits.  # noqa: E501

        A correlation ID associated with requests related to this event  # noqa: E501

        :return: The trace_id of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this AuthAudits.

        A correlation ID associated with requests related to this event  # noqa: E501

        :param trace_id: The trace_id of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    @property
    def session(self):
        """Gets the session of this AuthAudits.  # noqa: E501

        The session associated with tokens related to this event. This can be used to tie the actions undertaking by requests bearing tokens with the same session back to the authentication events which created the tokens.   # noqa: E501

        :return: The session of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._session

    @session.setter
    def session(self, session):
        """Sets the session of this AuthAudits.

        The session associated with tokens related to this event. This can be used to tie the actions undertaking by requests bearing tokens with the same session back to the authentication events which created the tokens.   # noqa: E501

        :param session: The session of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._session = session

    @property
    def issuer(self):
        """Gets the issuer of this AuthAudits.  # noqa: E501

        The issuer the user logged in to.  # noqa: E501

        :return: The issuer of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this AuthAudits.

        The issuer the user logged in to.  # noqa: E501

        :param issuer: The issuer of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def client_id(self):
        """Gets the client_id of this AuthAudits.  # noqa: E501

        The client id of the web application, client, etc. that the user is logging in with. Note that this is not the id of the `IssuerClient`, but rather the id presented to the authentication system to identify that client. This corresponds to `name` in the `IssuerClient`.   # noqa: E501

        :return: The client_id of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this AuthAudits.

        The client id of the web application, client, etc. that the user is logging in with. Note that this is not the id of the `IssuerClient`, but rather the id presented to the authentication system to identify that client. This corresponds to `name` in the `IssuerClient`.   # noqa: E501

        :param client_id: The client_id of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def application_name(self):
        """Gets the application_name of this AuthAudits.  # noqa: E501

        The name of the application within the system the user is logging in to.  # noqa: E501

        :return: The application_name of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._application_name

    @application_name.setter
    def application_name(self, application_name):
        """Sets the application_name of this AuthAudits.

        The name of the application within the system the user is logging in to.  # noqa: E501

        :param application_name: The application_name of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._application_name = application_name

    @property
    def login_org_id(self):
        """Gets the login_org_id of this AuthAudits.  # noqa: E501

        The id of the organisation that the user is logging in to. Note that this is disctinct from the `org_id` field, which is tied to the issuer. This id is tied to the application.   # noqa: E501

        :return: The login_org_id of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._login_org_id

    @login_org_id.setter
    def login_org_id(self, login_org_id):
        """Sets the login_org_id of this AuthAudits.

        The id of the organisation that the user is logging in to. Note that this is disctinct from the `org_id` field, which is tied to the issuer. This id is tied to the application.   # noqa: E501

        :param login_org_id: The login_org_id of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._login_org_id = login_org_id

    @property
    def login_org_name(self):
        """Gets the login_org_name of this AuthAudits.  # noqa: E501

        The name of the organisation that the user is logging in to. This corresponds to `login_org_id`.   # noqa: E501

        :return: The login_org_name of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._login_org_name

    @login_org_name.setter
    def login_org_name(self, login_org_name):
        """Sets the login_org_name of this AuthAudits.

        The name of the organisation that the user is logging in to. This corresponds to `login_org_id`.   # noqa: E501

        :param login_org_name: The login_org_name of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._login_org_name = login_org_name

    @property
    def upstream_idp(self):
        """Gets the upstream_idp of this AuthAudits.  # noqa: E501

        The name of the identity provider proving the identity of the user.   # noqa: E501

        :return: The upstream_idp of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._upstream_idp

    @upstream_idp.setter
    def upstream_idp(self, upstream_idp):
        """Sets the upstream_idp of this AuthAudits.

        The name of the identity provider proving the identity of the user.   # noqa: E501

        :param upstream_idp: The upstream_idp of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._upstream_idp = upstream_idp

    @property
    def stage(self):
        """Gets the stage of this AuthAudits.  # noqa: E501

        The stage of the login process. This identifies where in the pipeline the event was generated.   # noqa: E501

        :return: The stage of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._stage

    @stage.setter
    def stage(self, stage):
        """Sets the stage of this AuthAudits.

        The stage of the login process. This identifies where in the pipeline the event was generated.   # noqa: E501

        :param stage: The stage of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._stage = stage

    @property
    def user_agent(self):
        """Gets the user_agent of this AuthAudits.  # noqa: E501

        The user agent of the client used to perform the login.   # noqa: E501

        :return: The user_agent of this AuthAudits.  # noqa: E501
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """Sets the user_agent of this AuthAudits.

        The user agent of the client used to perform the login.   # noqa: E501

        :param user_agent: The user_agent of this AuthAudits.  # noqa: E501
        :type: str
        """

        self._user_agent = user_agent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthAudits):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuthAudits):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.access_requests import AccessRequests  # noqa: E501
from agilicus_api.rest import ApiException

class TestAccessRequests(unittest.TestCase):
    """AccessRequests unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AccessRequests
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.access_requests.AccessRequests()  # noqa: E501
        if include_optional :
            return AccessRequests(
                metadata = agilicus_api.models.metadata_with_only_id.MetadataWithOnlyId(
                    id = '123', ), 
                status = agilicus_api.models.access_requests_status.AccessRequestsStatus(
                    user = {"id":"as3sdfl","first_name":"Example","last_name":"User","email":"user@example.com","type":"user"}, 
                    user_requests = [
                        agilicus_api.models.user_request_info.UserRequestInfo(
                            metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                            spec = agilicus_api.models.user_request_info_spec.UserRequestInfoSpec(
                                user_id = 'tuU7smH86zAXMl76sua6xQ', 
                                org_id = 'IAsl3dl40aSsfLKiU76', 
                                requested_resource = 'phone', 
                                requested_sub_resource = 'self', 
                                requested_resource_type = 'application_access', 
                                request_information = 'I need this to do my job', 
                                state = 'pending', ), )
                        ], )
            )
        else :
            return AccessRequests(
                metadata = agilicus_api.models.metadata_with_only_id.MetadataWithOnlyId(
                    id = '123', ),
                status = agilicus_api.models.access_requests_status.AccessRequestsStatus(
                    user = {"id":"as3sdfl","first_name":"Example","last_name":"User","email":"user@example.com","type":"user"}, 
                    user_requests = [
                        agilicus_api.models.user_request_info.UserRequestInfo(
                            metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                            spec = agilicus_api.models.user_request_info_spec.UserRequestInfoSpec(
                                user_id = 'tuU7smH86zAXMl76sua6xQ', 
                                org_id = 'IAsl3dl40aSsfLKiU76', 
                                requested_resource = 'phone', 
                                requested_sub_resource = 'self', 
                                requested_resource_type = 'application_access', 
                                request_information = 'I need this to do my job', 
                                state = 'pending', ), )
                        ], ),
        )

    def testAccessRequests(self):
        """Test AccessRequests"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
